##  Avoid Over-Scoping Filters
Filters are powerful tools in data analysis, but scoping them too tightly can lead to reductive results. For example, selecting only "Perfect" for the functional fit or "Adequate" for the technical fit can:
  * Hide problematic data that the KPI is designed to expose.
  * Distort drilldown results, leading to poor insights or false positives.


Consider the KPI "Functional fit of applications." If you scope the "Functional Fit" filter to include only "Perfect," this excludes all poorly performing applications from the analysis. As a result, the drilldown lacks actionable insights because it no longer highlights areas needing improvement.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
